
use CGI qw/:standard *table/;
use strict;
use warnings; 
use DBI;

our $VERSION=0.02;

# Copyright Morten Sickel 2005
# Morten@sickel.net
#
# licenced under the GPL

# Parts of the system scripts are from https://lists.balabit.hu/pipermail/syslog-ng/2002-April/003249.html

# Set the correct values for postgresql server host, user name and password below
my $host='dva';
my $user='httpd';
my $pass='';
# Location of the stylesheet:
my  $stylesheet='http://www.hhv3/~morten/syslog.css'
# Showsql causes a print of the actual sql sentence on the web page if true
my $showsql=0;
# $include_all is a string being used to flag that information from all hosts shall be shown
my $include_all = '-- all servers --'; 
# $defaultlimit is the default number of entries that will be shown
my $defaultlimit=200;

#
#
#   Nothing to change below here..
#
#
#
#


my @array;
$|++;
our $dbhandle=DBI->connect("dbi:Pg:dbname=syslog;host=$host",$user)  || print p(em("cannot connect to databaseserver $host"));
$dbhandle->{ChopBlanks}=1;

# The hosts and facilities arrays are cached to speed up processing;

our @facilities;
unless ($#facilities+1){
    my $qfacility=$dbhandle-> 
	prepare('select name from facility');
    $qfacility->execute;
    while (@array=$qfacility->fetchrow_array){
	push @facilities,$array[0];
    }
}

our @hosts; 
# Must fetch the hosts list only if it does not already exist
unless ($#hosts+1){
    my $qhost=$dbhandle->
	prepare('select name from hostname');
    $qhost->execute;
    while (@array=$qhost->fetchrow_array){
	push @hosts,$array[0];
    }
}

my @servers=($include_all,sort(@hosts));

my @priorities=reverse qw/  debug  info notice warning err crit alert emerg /;

# The following block prints out the web page down through the form for selecting data

print 
    header,
    start_html(-title=>'Syslog overview -- '.param('server'),
	       -style=>{src=>$stylesheet}
	       ),
    start_form(-method=>'GET'),
    "<label for='server'>Select server </label> ",
    popup_menu (-name=>'server',-id=>'server',-class=>'popup',
		-values=>[@servers]),br,
    "<label for='priority'>Lowest priority  </label> ",
    , popup_menu (-name=>'priority',-id=>'priority',-class=>'popup',
		  -values=>[@priorities]),br,
    "<label for='facility'>Facilities  </label> ",    

    popup_menu (-name=>'facility',-id=>'facility',-class=>'popup',
		  -multiple=>'multiple',-values=>[@facilities]),
    checkbox(-name=>'allfacilities',
                           -Checked=>0,
                           -value=>'show',
	     -label=>'All facilities'),
    br,
    "<label for='entries' >Number of entries </label> ",
    
    " ",textfield(-name=>'entries',-id=>'entries',-value=>$defaultlimit,
		  -class=>'textfield',),"<br />",
    submit(-class=>'submit'),
    end_form,
    hr;

if (param()) {
    my @facilities= param('facility') unless param('allfacilities') eq 'show';
    my $limit=param('entries')*1;# || $defaultlimit;
    my %priorities=(debug=>1,
		    info=>2,
		    notice=>3,
		    warning=>4,
		    err=>5,
		    crit=>6,
		    alert=>7,
		    emerg=>8);
    my $pri=$priorities{param('priority')};
    my $query=
	'select sent,hostname,facility,priority.name as priority,text '.
	'from message, priority'.
	" where priorityid >= $pri and priorityid = priority.id " ;
    $query.=" and hostname=? " unless param('server') eq $include_all;
    $query.=" and facility in(?".",?"x($#facilities).")" if (@facilities)+0;
    $query.=" order by message.id desc limit $limit";

    print "Data from ",em(param('server')),
    "  Priorites >= ",em(param('priority'))," Facilities : "; 
    {
	local $,=', ';
	print @facilities;
    }
    print hr;
    print "$query",hr if $showsql;

    # Puts the chosen (if any) host on the @facilites array that will afterwards be
    # used as an argument for execute 
    unshift  @facilities, param('server') unless param('server') eq $include_all;
    my $queryh=$dbhandle->prepare($query) or print p(em('Cannot prepare'));

    # Remember, the chosen host (if any) is put in element 0 of facilities
    unless ($queryh->execute(@facilities)){ 
	print (em("Cannot execute<br/>$query"));
    }else{
	print start_table,"<tr>";
	print th($_) foreach (qw/Time host facility priority message/);
	print "</tr>";
	# A lookup table to map priorities to css-classes and finally colors
	our %class = (debug=>'none',
		     info=>'none',
		     notice=>'low',
		     warning=>'low',
		     err=>'med',
		     crit=>'med',
		     alert=>'high',
		     emerg=>'high');
	my $nrows;
	while (@array = $queryh->fetchrow_array)
	{
	    $nrows++;
	    print "<tr class=\"",$class{$array[3]},"\"><td>";
	    {    local $,='</td><td>';
		 print @array}
	    print "</td></tr>\n";
	}
	print end_table;
	print "<p>$nrows items</p>";
    }
}
print hr,"Copyright <a href=\"http://sickel.net/syslog/\">Morten Sickel</a> 2005 <br />\n",
"Licenced under the GPL as by February 2005<hr />".
"</body></html>";
