
CREATE TABLE message (
    received timestamp without time zone,
    sent timestamp without time zone,
    hostname character varying(256),
    facility character varying(16),
    msg_priority character varying(16),
    text text,
    id serial NOT NULL,
    priorityid integer,
    facilityid integer
);


GRANT SELECT ON TABLE message TO httpd;
ALTER TABLE ONLY message
    ADD CONSTRAINT msg_table_pkey PRIMARY KEY (id);


CREATE VIEW priority_summ AS
    SELECT count(msg_table.id) AS count, msg_table.msg_priority FROM message msg_table GROUP BY msg_table.msg_priority;

GRANT SELECT ON TABLE priority_summ TO httpd;


CREATE VIEW host_summ AS
    SELECT count(msg_table.id) AS count, msg_table.hostname FROM message msg_table GROUP BY msg_table.hostname;


GRANT SELECT ON TABLE host_summ TO httpd;


CREATE VIEW last5 AS
    SELECT msg_table.received AS msg_rcv_time, msg_table.sent AS msg_sent_time, msg_table.hostname, msg_table.facility AS msg_facility, msg_table.msg_priority, msg_table.text AS msg_text, msg_table.id AS msg_id FROM message msg_table ORDER BY msg_table.id DESC LIMIT 5;

GRANT SELECT ON TABLE last5 TO httpd;


CREATE TABLE priority (
    id integer NOT NULL,
    name character(10),
    altname character(5)
);


INSERT INTO priority VALUES (1, 'debug     ', NULL);
INSERT INTO priority VALUES (2, 'info      ', NULL);
INSERT INTO priority VALUES (3, 'notice    ', NULL);
INSERT INTO priority VALUES (4, 'warning   ', 'warn ');
INSERT INTO priority VALUES (5, 'err       ', 'error');
INSERT INTO priority VALUES (6, 'crit      ', NULL);
INSERT INTO priority VALUES (7, 'alert     ', NULL);
INSERT INTO priority VALUES (8, 'emerg     ', 'panic');



GRANT SELECT ON TABLE priority TO httpd;

ALTER TABLE ONLY priority
    ADD CONSTRAINT priority_pkey PRIMARY KEY (id);


CREATE TABLE facility (
    id serial NOT NULL,
    name character(15)
);

GRANT SELECT ON TABLE facility TO httpd;

ALTER TABLE ONLY facility
    ADD CONSTRAINT facilities_pkey PRIMARY KEY (id);


CREATE TABLE hostname (
    id serial NOT NULL,
    name character(20) NOT NULL
);

ALTER TABLE ONLY hostname
    ADD CONSTRAINT hostname_pkey PRIMARY KEY (id);

GRANT SELECT ON TABLE hostname TO httpd;


CREATE TABLE message_old (
    id integer,
    received timestamp without time zone,
    sent timestamp without time zone,
    hostname character varying(256),
    facility character varying(16),
    priority character varying(16),
    text text,
    priorityid integer,
    facilityid integer,

);


CREATE INDEX msg_hostname ON message USING btree (hostname);
CREATE INDEX msg_facility ON message USING btree (facility);
CREATE INDEX idx_priname ON priority USING btree (name);
CREATE INDEX msg_priority ON message USING btree (priorityid);
 

